#[repr(C)]pub struct OtaDownloaderFetchBlobResponse {
pub bytes_fetched: u64,
}Fields
bytes_fetched: u64Trait Implementations
Sourceimpl Clone for OtaDownloaderFetchBlobResponse
impl Clone for OtaDownloaderFetchBlobResponse
Sourcefn clone(&self) -> OtaDownloaderFetchBlobResponse
fn clone(&self) -> OtaDownloaderFetchBlobResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OtaDownloaderFetchBlobResponse
Sourceimpl<D> Decode<OtaDownloaderFetchBlobResponse, D> for OtaDownloaderFetchBlobResponsewhere
D: ResourceDialect,
impl<D> Decode<OtaDownloaderFetchBlobResponse, D> for OtaDownloaderFetchBlobResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> OtaDownloaderFetchBlobResponse
fn new_empty() -> OtaDownloaderFetchBlobResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<OtaDownloaderFetchBlobResponse, D> for &OtaDownloaderFetchBlobResponsewhere
D: ResourceDialect,
impl<D> Encode<OtaDownloaderFetchBlobResponse, D> for &OtaDownloaderFetchBlobResponsewhere
D: ResourceDialect,
impl Eq for OtaDownloaderFetchBlobResponse
Sourceimpl Ord for OtaDownloaderFetchBlobResponse
impl Ord for OtaDownloaderFetchBlobResponse
Sourcefn cmp(&self, other: &OtaDownloaderFetchBlobResponse) -> Ordering
fn cmp(&self, other: &OtaDownloaderFetchBlobResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for OtaDownloaderFetchBlobResponse
impl PartialOrd for OtaDownloaderFetchBlobResponse
impl Persistable for OtaDownloaderFetchBlobResponse
impl StructuralPartialEq for OtaDownloaderFetchBlobResponse
Sourceimpl TypeMarker for OtaDownloaderFetchBlobResponse
impl TypeMarker for OtaDownloaderFetchBlobResponse
Sourcetype Owned = OtaDownloaderFetchBlobResponse
type Owned = OtaDownloaderFetchBlobResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for OtaDownloaderFetchBlobResponse
impl ValueTypeMarker for OtaDownloaderFetchBlobResponse
Sourcetype Borrowed<'a> = &'a OtaDownloaderFetchBlobResponse
type Borrowed<'a> = &'a OtaDownloaderFetchBlobResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<OtaDownloaderFetchBlobResponse as TypeMarker>::Owned,
) -> <OtaDownloaderFetchBlobResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<OtaDownloaderFetchBlobResponse as TypeMarker>::Owned, ) -> <OtaDownloaderFetchBlobResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for OtaDownloaderFetchBlobResponse
impl RefUnwindSafe for OtaDownloaderFetchBlobResponse
impl Send for OtaDownloaderFetchBlobResponse
impl Sync for OtaDownloaderFetchBlobResponse
impl Unpin for OtaDownloaderFetchBlobResponse
impl UnsafeUnpin for OtaDownloaderFetchBlobResponse
impl UnwindSafe for OtaDownloaderFetchBlobResponse